{% extends "security/login_user.html" %}

{% block title %}{{ _('Password Reset') }}{% endblock %}


{% block page_content %}
  {% block form %}
  <h1>{{ _('Send password reset instructions') }}</h1>
  <form action="{{ url_for_security('forgot_password') }}" method="POST" name="forgot_password_form">
    {{ forgot_password_form.hidden_tag() }}
    {{ render_field_with_errors(forgot_password_form.email) }} 
    {{ render_field(forgot_password_form.submit) }}
  </form>
  {% endblock form %}
{% endblock page_content %}

{% block custom_links %}
  <p class="mt-3 mb-1">
    <a href="{{ url_for_security('login') }}">{{ _('Log in') }}</a>
  </p>
  {% if config.SECURITY_REGISTERABLE %}
    <p class="mb-0">
      <a href="{{ url_for_security('register') }}" class="text-center">
        {{ _('Register a new membership') }}
      </a>
    </p>
  {% endif %}
{% endblock %}