{% extends "security/login_user.html" %}
{% from "security/_macros.html" import render_field_with_errors, render_field %}

{% block title %}{{ _('Password Reset') }}{% endblock %}

{% block page_content %}
<h1>{{ _('Reset password') }}</h1>
<form action="{{ url_for_security('reset_password', token=reset_password_token) }}" method="POST" name="reset_password_form">
  {{ reset_password_form.hidden_tag() }}
  {{ render_field_with_errors(reset_password_form.password) }}
  {{ render_field_with_errors(reset_password_form.password_confirm) }}
  {{ render_field(reset_password_form.submit) }}
</form>
{% endblock %}

{% block custom_links %}
  <p class="mt-3 mb-1">
    <a href="{{ url_for_security('login') }}">{{ _('Log in as different user') }}</a>
  </p>
  {% if config.SECURITY_REGISTERABLE %}
    <p class="mb-0">
      <a href="{{ url_for_security('register') }}" class="text-center">
        {{ _('Register a new membership') }}
      </a>
    </p>
  {% endif %}
{% endblock %}