<form class="form-inline ml-0 ml-md-3" action="{{ url_for(config.THEME_SEARCH_ENDPOINT) }}" method="get">
    <div class="input-group input-group-sm">
        <input name="q" type="search" class="form-control form-control-navbar"
            placeholder="{{ _('Search') }}" aria-label="{{ _('Search') }}">
        <div class="input-group-append">
            <button class="btn btn-navbar" type="submit">
                <i class="fas fa-search"></i>
            </button>
        </div>
    </div>
</form>