<!--| includes/meta.html |-->
<meta charset="utf-8">
<meta name="viewport" content="width=device-width, initial-scale=1">
<meta http-equiv="x-ua-compatible" content="ie=edge">
<meta name="description" content="{% block meta_description %}{% endblock %}">
<meta name="keywords" content="{% block meta_keywords %}{% endblock %}">
<!--|END|-->
