{% extends 'security/login_user.html' %}

{% block body_class %}login-page{% endblock %}

{% block page_content %}
    <h1>{{ _("Please Enter Your Password") }}</h1>
    <form action="{{ url_for_security("two_factor_verify_password") }}" method="POST"
          name="two_factor_verify_password_form">
        {{ two_factor_verify_password_form.hidden_tag() }}
        {{ render_field_with_errors(two_factor_verify_password_form.password, placeholder="enter password") }}
        {{ render_field(two_factor_verify_password_form.submit) }}
    </form>
{% endblock %}