{% if security.registerable or security.recoverable or security.confirmable %}
<h2>Menu</h2>
<ul>
  <li><a href="{{ url_for_security('login') }}{% if 'next' in request.args %}?next={{ request.args.next|urlencode }}{% endif %}">Login</a></li>
  {% if security.registerable %}
  <li><a href="{{ url_for_security('register') }}{% if 'next' in request.args %}?next={{ request.args.next|urlencode }}{% endif %}">Register</a><br/></li>
  {% endif %}
  {% if security.recoverable %}
  <li><a href="{{ url_for_security('forgot_password') }}">Forgot password</a><br/></li>
  {% endif %}
  {% if security.confirmable %}
  <li><a href="{{ url_for_security('send_confirmation') }}">Confirm account</a></li>
  {% endif %}
</ul>
{% endif %}
